@@ -296,9 +296,9 @@ changed by this option and should be set via the <span class="strong"><strong>--
 </dd>
 <dt>
 <span class="term">
-<span class="strong"><strong>-d</strong></span> <span class="emphasis"><em>URL</em></span> <span class="emphasis"><em><span class="scheme">params</span></em></span>
+<span class="strong"><strong>-d</strong></span> <span class="emphasis"><em>URL</em></span> <span class="emphasis"><em>params</em></span>
 , </span><span class="term">
-<span class="strong"><strong>--dest</strong></span> <span class="emphasis"><em>URL</em></span> <span class="emphasis"><em><span class="scheme">params</span></em></span>
+<span class="strong"><strong>--dest</strong></span> <span class="emphasis"><em>URL</em></span> <span class="emphasis"><em>params</em></span>
 </span>
 </dt>
 <dd>
