@@ -12,39 +12,39 @@
 </tr></table>
 <hr>
 </div>
-<div class="section" title="16.4. Best Practices For Developing Portable Code">
+<div class="section">
 <div class="titlepage"><div><div><h2 class="title" style="clear: both">
 <a name="portable_code"></a>16.4. Best Practices For Developing Portable Code</h2></div></div></div>
-<div class="toc"><dl>
-<dt><span class="section"><a href="portable_code.php#idp41230800">16.4.1. Supported Platforms</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp32907488">16.4.2. Packaging of Software</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp40759024">16.4.3. MPI Codes</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp40760656">16.4.4. Maximum Running Time of Codes</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp40762416">16.4.5. Codes cannot specify the directory in which they should be
+<div class="toc"><dl class="toc">
+<dt><span class="section"><a href="portable_code.php#idp48792912">16.4.1. Supported Platforms</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp49483232">16.4.2. Packaging of Software</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp60117088">16.4.3. MPI Codes</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp60118720">16.4.4. Maximum Running Time of Codes</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp59281520">16.4.5. Codes cannot specify the directory in which they should be
       run</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp36253024">16.4.6. No hard-coded paths</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp36254608">16.4.7. Wrapping legacy codes with a shell wrapper</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp39588784">16.4.8. Propogating back the right exitcode</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp39593360">16.4.9. Static vs. Dynamically Linked Libraries</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp35863776">16.4.10. Temporary Files</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp35865600">16.4.11. Handling of stdio</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp34457328">16.4.12. Configuration Files</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp36343472">16.4.13. Code Invocation and input data staging by Pegasus</a></span></dt>
-<dt><span class="section"><a href="portable_code.php#idp34712496">16.4.14. Logical File naming in DAX</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp47616528">16.4.6. No hard-coded paths</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp47618112">16.4.7. Wrapping legacy codes with a shell wrapper</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp47619776">16.4.8. Propogating back the right exitcode</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp47420896">16.4.9. Static vs. Dynamically Linked Libraries</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp57706896">16.4.10. Temporary Files</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp57708720">16.4.11. Handling of stdio</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp60629440">16.4.12. Configuration Files</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp57245216">16.4.13. Code Invocation and input data staging by Pegasus</a></span></dt>
+<dt><span class="section"><a href="portable_code.php#idp49387968">16.4.14. Logical File naming in DAX</a></span></dt>
 </dl></div>
 <p>This document lists out issues for the algorithm developers to keep
     in mind while developing the respective codes. Keeping these in mind will
     alleviate a lot of problems while trying to run the codes on the Grid
     through workflows.</p>
-<div class="section" title="16.4.1. Supported Platforms">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp41230800"></a>16.4.1. Supported Platforms</h3></div></div></div>
+<a name="idp48792912"></a>16.4.1. Supported Platforms</h3></div></div></div>
 <p>Most of the hosts making a Grid run variants of Linux or in some
       case Solaris. The Grid middleware mostly supports UNIX and it's
       variants.</p>
-<div class="section" title="16.4.1.1. Running on Windows">
+<div class="section">
 <div class="titlepage"><div><div><h4 class="title">
-<a name="idp32904736"></a>16.4.1.1. Running on Windows</h4></div></div></div>
+<a name="idp48794224"></a>16.4.1.1. Running on Windows</h4></div></div></div>
 <p>The majority of the machines making up the various Grid sites
         run Linux. In fact, there is no widespread deployment of a
         Windows-based Grid. Currently, the server side software of Globus does
@@ -59,9 +59,9 @@
         of a windows cluster running Condor as it's scheduler.</p>
 </div>
 </div>
-<div class="section" title="16.4.2. Packaging of Software">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp32907488"></a>16.4.2. Packaging of Software</h3></div></div></div>
+<a name="idp49483232"></a>16.4.2. Packaging of Software</h3></div></div></div>
 <p>As far as possible, binary packages (preferably statically linked)
       of the codes should be provided. If for some reason the codes, need to
       be built from the source then they should have an associated makefile (
@@ -74,18 +74,18 @@
       all the external libraries that need to be installed can only be
       installed as non-root in non-standard locations.</p>
 </div>
-<div class="section" title="16.4.3. MPI Codes">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp40759024"></a>16.4.3. MPI Codes</h3></div></div></div>
+<a name="idp60117088"></a>16.4.3. MPI Codes</h3></div></div></div>
 <p>If any of the algorithm codes are MPI based, they should contact
       the Grid group. MPI can be run on the Grid but the codes need to be
       compiled against the installed MPI libraries on the various Grid sites.
       The pegasus group has some experience running MPI code through
       PBS.</p>
 </div>
-<div class="section" title="16.4.4. Maximum Running Time of Codes">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp40760656"></a>16.4.4. Maximum Running Time of Codes</h3></div></div></div>
+<a name="idp60118720"></a>16.4.4. Maximum Running Time of Codes</h3></div></div></div>
 <p>Each of the Grid sites has a policy on the maximum time for which
       they will allow a job to run. The algorithms catalog should have the
       maximum time (in minutes) that the job can run for. This information is
@@ -93,9 +93,9 @@
       not kill a job before that published time expires. It is OK, if the job
       runs only a fraction of the max time.</p>
 </div>
-<div class="section" title="16.4.5. Codes cannot specify the directory in which they should be run">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp40762416"></a>16.4.5. Codes cannot specify the directory in which they should be
+<a name="idp59281520"></a>16.4.5. Codes cannot specify the directory in which they should be
       run</h3></div></div></div>
 <p>Codes are installed in some standard location on the Grid Sites or
       staged on demand. However, they are not invoked from directories where
@@ -111,26 +111,26 @@
       workflow system can set appropriate environment variables while
       launching jobs on the Grid.</p>
 </div>
-<div class="section" title="16.4.6. No hard-coded paths">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp36253024"></a>16.4.6. No hard-coded paths</h3></div></div></div>
+<a name="idp47616528"></a>16.4.6. No hard-coded paths</h3></div></div></div>
 <p>The algorithms should not hard-code any directory paths in the
       code. All directories paths should be picked up explicitly either from
       the environment (specifying environment variables) or from command line
       options passed to the algorithm code.</p>
 </div>
-<div class="section" title="16.4.7. Wrapping legacy codes with a shell wrapper">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp36254608"></a>16.4.7. Wrapping legacy codes with a shell wrapper</h3></div></div></div>
+<a name="idp47618112"></a>16.4.7. Wrapping legacy codes with a shell wrapper</h3></div></div></div>
 <p>When wrapping a legacy code in a script (or another program), it
       is necessary that the wrapper knows where the executable lives. This is
       accomplished using an environmental variable. Be sure to include this
       detail in the component description when submitting a component for use
       on the Grid -- include a brief descriptive name like GDA_BIN.</p>
 </div>
-<div class="section" title="16.4.8. Propogating back the right exitcode">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp39588784"></a>16.4.8. Propogating back the right exitcode</h3></div></div></div>
+<a name="idp47619776"></a>16.4.8. Propogating back the right exitcode</h3></div></div></div>
 <p>A job in the workflow is only released for execution if its
       parents have executed successfully. Hence, it is very important that the
       algorithm codes exit with the correct error code in case of success and
@@ -154,9 +154,9 @@ $ echo $?
       code in a script that tests some final condition (such as the presence
       or format of a result file) and uses exit to return correctly.</p>
 </div>
-<div class="section" title="16.4.9. Static vs. Dynamically Linked Libraries">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp39593360"></a>16.4.9. Static vs. Dynamically Linked Libraries</h3></div></div></div>
+<a name="idp47420896"></a>16.4.9. Static vs. Dynamically Linked Libraries</h3></div></div></div>
 <p>Since there is no way to know the profile of the machine that will
       be executing the code, it is important that dynamically linked libraries
       are avoided or that reliance on them is kept to a minimum. For example,
@@ -168,9 +168,9 @@ $ echo $?
       <code class="envar">LD_LIBRARY_PATH</code> for the algorithm in the transformation
       catalog for each site.</p>
 </div>
-<div class="section" title="16.4.10. Temporary Files">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp35863776"></a>16.4.10. Temporary Files</h3></div></div></div>
+<a name="idp57706896"></a>16.4.10. Temporary Files</h3></div></div></div>
 <p>If the algorithm codes create temporary files during execution,
       they should be cleared by the codes in case of errors and success
       terminations. The algorithm codes will run on scratch file systems that
@@ -179,9 +179,9 @@ $ echo $?
       space. The temporary files are the files that are not being tracked
       explicitly through the workflow generation process.</p>
 </div>
-<div class="section" title="16.4.11. Handling of stdio">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp35865600"></a>16.4.11. Handling of stdio</h3></div></div></div>
+<a name="idp57708720"></a>16.4.11. Handling of stdio</h3></div></div></div>
 <p>When writing a new application, it often appears feasible to use
       <span class="emphasis"><em>stdin</em></span> for a single file data, and
       <span class="emphasis"><em>stdout</em></span> for a single file output data. The
@@ -211,9 +211,9 @@ $ echo $?
       arguments instead relying on <span class="emphasis"><em>stdin</em></span> and
       <span class="emphasis"><em>stdout</em></span>.</p>
 </div>
-<div class="section" title="16.4.12. Configuration Files">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp34457328"></a>16.4.12. Configuration Files</h3></div></div></div>
+<a name="idp60629440"></a>16.4.12. Configuration Files</h3></div></div></div>
 <p>If your code requires a configuration file to run and the
       configuration changes from one run to another, then this file needs to
       be tracked explicitly via the Pegasus WMS. The configuration file should
@@ -224,9 +224,9 @@ $ echo $?
       as $ENV-VAR/xyz where <code class="envar">$ENV-VAR</code> is set during execution
       time and evaluated by your application code internally.</p>
 </div>
-<div class="section" title="16.4.13. Code Invocation and input data staging by Pegasus">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp36343472"></a>16.4.13. Code Invocation and input data staging by Pegasus</h3></div></div></div>
+<a name="idp57245216"></a>16.4.13. Code Invocation and input data staging by Pegasus</h3></div></div></div>
 <p>Pegasus will create one temporary directory per workflow on each
       site where the workflow is planned. Pegasus will stage all the files
       required for the execution of the workflow in these temporary
@@ -256,12 +256,12 @@ $ echo $?
       specifies the name and path of where the results should be
       written.</p>
 </div>
-<div class="section" title="16.4.14. Logical File naming in DAX">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp34712496"></a>16.4.14. Logical File naming in DAX</h3></div></div></div>
+<a name="idp49387968"></a>16.4.14. Logical File naming in DAX</h3></div></div></div>
 <p>The logical file names used by your code can be of two
       types.</p>
-<div class="itemizedlist"><ul class="itemizedlist" type="disc">
+<div class="itemizedlist"><ul class="itemizedlist" style="list-style-type: disc; ">
 <li class="listitem"><p>Without a directory path e.g. <code class="filename">f.a</code>,
           <code class="filename">f.b</code> etc</p></li>
 <li class="listitem"><p>With a directory path e.g. <code class="filename">a/1/f.a</code>,
@@ -275,7 +275,7 @@ $ echo $?
 <pre class="programlisting">$/bin/test --input f.a --output f.b</pre>
 <p>OR</p>
 <pre class="programlisting">$/bin/test --input a/1/f.a --output b/1/f.b</pre>
-<div class="note" title="Note" style="margin-left: 0.5in; margin-right: 0.5in;">
+<div class="note" style="margin-left: 0.5in; margin-right: 0.5in;">
 <h3 class="title">Note</h3>
 <p>A logical file name should never be an absolute file path, e.g.
         /a/1/f.a In other words, there should not be a starting slash (/) in a
