@@ -12,25 +12,25 @@
 </tr></table>
 <hr>
 </div>
-<div class="section" title="12.2. Profiles">
+<div class="section">
 <div class="titlepage"><div><div><h2 class="title" style="clear: both">
 <a name="profiles"></a>12.2. Profiles</h2></div></div></div>
-<div class="toc"><dl>
-<dt><span class="section"><a href="profiles.php#idp42251344">12.2.1. Profile Structure Heading</a></span></dt>
-<dt><span class="section"><a href="profiles.php#idp32676992">12.2.2. Sources for Profiles</a></span></dt>
-<dt><span class="section"><a href="profiles.php#idp45661616">12.2.3. Profiles Conflict Resolution</a></span></dt>
-<dt><span class="section"><a href="profiles.php#idp45668640">12.2.4. Details of Profile Handling</a></span></dt>
+<div class="toc"><dl class="toc">
+<dt><span class="section"><a href="profiles.php#idp47817136">12.2.1. Profile Structure Heading</a></span></dt>
+<dt><span class="section"><a href="profiles.php#idp58123696">12.2.2. Sources for Profiles</a></span></dt>
+<dt><span class="section"><a href="profiles.php#idp53714432">12.2.3. Profiles Conflict Resolution</a></span></dt>
+<dt><span class="section"><a href="profiles.php#idp55397360">12.2.4. Details of Profile Handling</a></span></dt>
 <dt><span class="section"><a href="profiles.php#env_profiles">12.2.5. The Env Profile Namespace</a></span></dt>
-<dt><span class="section"><a href="profiles.php#idp46471920">12.2.6. The Globus Profile Namespace</a></span></dt>
+<dt><span class="section"><a href="profiles.php#idp54620688">12.2.6. The Globus Profile Namespace</a></span></dt>
 <dt><span class="section"><a href="profiles.php#condor_profiles">12.2.7. The Condor Profile Namespace</a></span></dt>
 <dt><span class="section"><a href="profiles.php#dagman_profiles">12.2.8. The Dagman Profile Namespace</a></span></dt>
 <dt><span class="section"><a href="profiles.php#pegasus_profiles">12.2.9. The Pegasus Profile Namespace</a></span></dt>
 <dt><span class="section"><a href="profiles.php#hints_profiles">12.2.10. The Hints Profile Namespace</a></span></dt>
 </dl></div>
 <p></p>
-<div class="section" title="12.2.1. Profile Structure Heading">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp42251344"></a>12.2.1. Profile Structure Heading</h3></div></div></div>
+<a name="idp47817136"></a>12.2.1. Profile Structure Heading</h3></div></div></div>
 <p>All profiles are triples comprised of a namespace, a name or key,
       and a value. The namespace is a simple identifier. The key has only
       meaning within its namespace, and it's yet another identifier. There are
@@ -39,13 +39,13 @@
       context. However, each syntax will describe the underlying
       triple.</p>
 </div>
-<div class="section" title="12.2.2. Sources for Profiles">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp32676992"></a>12.2.2. Sources for Profiles</h3></div></div></div>
+<a name="idp58123696"></a>12.2.2. Sources for Profiles</h3></div></div></div>
 <p>Profiles may enter the job-processing stream at various stages.
       Depending on the requirements and scope a profile is to apply, profiles
       can be associated at</p>
-<div class="itemizedlist"><ul class="itemizedlist" type="disc">
+<div class="itemizedlist"><ul class="itemizedlist" style="list-style-type: disc; ">
 <li class="listitem"><p>as user property settings.</p></li>
 <li class="listitem"><p>dax level</p></li>
 <li class="listitem"><p>in the site catalog</p></li>
@@ -55,9 +55,9 @@
       context. This section shows the different profile sources and syntaxes.
       However, at the foundation of each profile lies the triple of namespace,
       key and value.</p>
-<div class="section" title="12.2.2.1. User Profiles in Properties">
+<div class="section">
 <div class="titlepage"><div><div><h4 class="title">
-<a name="idp32764352"></a>12.2.2.1. User Profiles in Properties</h4></div></div></div>
+<a name="idp58925040"></a>12.2.2.1. User Profiles in Properties</h4></div></div></div>
 <p>Users can specify all profiles in the properties files where the
         property name is <span class="bold"><strong>[namespace].key</strong></span> and
         <span class="bold"><strong>value</strong></span> of the property is the value of
@@ -96,9 +96,9 @@ pegasus.clusters.size 5
 
 pegasus.stagein.clusters 3</pre>
 </div>
-<div class="section" title="12.2.2.2. Profiles in DAX">
+<div class="section">
 <div class="titlepage"><div><div><h4 class="title">
-<a name="idp45989872"></a>12.2.2.2. Profiles in DAX</h4></div></div></div>
+<a name="idp58930624"></a>12.2.2.2. Profiles in DAX</h4></div></div></div>
 <p>The user can associate profiles with logical transformations in
         DAX. Environment settings required by a job's application, or a
         maximum estimate on the run-time are examples for profiles at this
@@ -114,9 +114,9 @@ pegasus.stagein.clusters 3</pre>
 &lt;/job&gt;
 </pre>
 </div>
-<div class="section" title="12.2.2.3. Profiles in Site Catalog">
+<div class="section">
 <div class="titlepage"><div><div><h4 class="title">
-<a name="idp45993216"></a>12.2.2.3. Profiles in Site Catalog</h4></div></div></div>
+<a name="idp47630768"></a>12.2.2.3. Profiles in Site Catalog</h4></div></div></div>
 <p>If it becomes necessary to limit the scope of a profile to a
         single site, these profiles should go into the site catalog. A profile
         in the site catalog applies to all jobs and all application run at the
@@ -143,9 +143,9 @@ pegasus.stagein.clusters 3</pre>
 &lt;/site&gt;
 </pre>
 </div>
-<div class="section" title="12.2.2.4. Profiles in Transformation Catalog">
+<div class="section">
 <div class="titlepage"><div><div><h4 class="title">
-<a name="idp32725984"></a>12.2.2.4. Profiles in Transformation Catalog</h4></div></div></div>
+<a name="idp47638608"></a>12.2.2.4. Profiles in Transformation Catalog</h4></div></div></div>
 <p>Some profiles require a narrower scope than the site catalog
         offers. Some profiles only apply to certain applications on certain
         sites, or change with each application and site.
@@ -200,9 +200,9 @@ pegasus.stagein.clusters 3</pre>
         directly in the editor.</p>
 </div>
 </div>
-<div class="section" title="12.2.3. Profiles Conflict Resolution">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp45661616"></a>12.2.3. Profiles Conflict Resolution</h3></div></div></div>
+<a name="idp53714432"></a>12.2.3. Profiles Conflict Resolution</h3></div></div></div>
 <p>Irrespective of where the profiles are specified, eventually the
       profiles are associated with jobs. Multiple sources may specify the same
       profile for the same job. For instance, DAX may specify an environment
@@ -220,15 +220,15 @@ pegasus.stagein.clusters 3</pre>
 <li class="listitem"><p>Profiles in Properties</p></li>
 </ol></div>
 </div>
-<div class="section" title="12.2.4. Details of Profile Handling">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp45668640"></a>12.2.4. Details of Profile Handling</h3></div></div></div>
+<a name="idp55397360"></a>12.2.4. Details of Profile Handling</h3></div></div></div>
 <p>The previous sections omitted some of the finer details for the
       sake of clarity. To understand some of the constraints that Pegasus
       imposes, it is required to look at the way profiles affect jobs.</p>
-<div class="section" title="12.2.4.1. Details of env Profiles">
+<div class="section">
 <div class="titlepage"><div><div><h4 class="title">
-<a name="idp45670032"></a>12.2.4.1. Details of env Profiles</h4></div></div></div>
+<a name="idp55398752"></a>12.2.4.1. Details of env Profiles</h4></div></div></div>
 <p>Profiles in the env namespace are translated to a
         semicolon-separated list of key-value pairs. The list becomes the
         argument for the Condor environment command in the job's submit
@@ -260,9 +260,9 @@ queue
         of environment variables in its executable and arguments
         setting.</p>
 </div>
-<div class="section" title="12.2.4.2. Details of globus Profiles">
+<div class="section">
 <div class="titlepage"><div><div><h4 class="title">
-<a name="idp46083664"></a>12.2.4.2. Details of globus Profiles</h4></div></div></div>
+<a name="idp61583344"></a>12.2.4.2. Details of globus Profiles</h4></div></div></div>
 <p>Profiles in the <span class="emphasis"><em>globus</em></span> Namespaces are
         translated into a list of paranthesis-enclosed equal-separated
         key-value pairs. The list becomes the value for the Condor
@@ -288,7 +288,7 @@ queue
         profile namespace.</p>
 </div>
 </div>
-<div class="section" title="12.2.5. The Env Profile Namespace">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
 <a name="env_profiles"></a>12.2.5. The Env Profile Namespace</h3></div></div></div>
 <p>The <span class="emphasis"><em>env</em></span> namespace allows users to specify
@@ -306,7 +306,7 @@ queue
       or the rc-client, it becomes necessary to set PEGASUS_HOME and
       GLOBUS_LOCATION even for jobs that run locally</p>
 <div class="table">
-<a name="idp46094000"></a><p class="title"><b>Table 12.1. Useful Environment Settings</b></p>
+<a name="idp49140944"></a><p class="title"><b>Table 12.1. Useful Environment Settings</b></p>
 <div class="table-contents"><table summary="Useful Environment Settings" border="1">
 <colgroup>
 <col>
@@ -356,9 +356,9 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
       settings through their profiles, all remote environment variables must
       be set through the means of <span class="emphasis"><em>env</em></span> profiles.</p>
 </div>
-<div class="section" title="12.2.6. The Globus Profile Namespace">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp46471920"></a>12.2.6. The Globus Profile Namespace</h3></div></div></div>
+<a name="idp54620688"></a>12.2.6. The Globus Profile Namespace</h3></div></div></div>
 <p>The <span class="emphasis"><em>globus</em></span> profile namespace encapsulates
       Globus resource specification language (RSL) instructions. The RSL
       configures settings and behavior of the remote scheduling system. Some
@@ -374,7 +374,7 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
       authoritative list of all possible RSL instructions refer to the Globus
       RSL specification.</p>
 <div class="table">
-<a name="idp36292096"></a><p class="title"><b>Table 12.2. Useful Globus RSL Instructions</b></p>
+<a name="idp52434800"></a><p class="title"><b>Table 12.2. Useful Globus RSL Instructions</b></p>
 <div class="table-contents"><table summary="Useful Globus RSL Instructions" border="1">
 <colgroup>
 <col>
@@ -474,7 +474,7 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
       need to specify remote environment settings, do not use the environment
       key in the globus profiles. Use one or more env profiles instead.</p>
 <div class="table">
-<a name="idp33054944"></a><p class="title"><b>Table 12.3. RSL Instructions that are not permissible</b></p>
+<a name="idp52203456"></a><p class="title"><b>Table 12.3. RSL Instructions that are not permissible</b></p>
 <div class="table-contents"><table summary="RSL Instructions that are not permissible" border="1">
 <colgroup>
 <col>
@@ -526,7 +526,7 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
 </div>
 <br class="table-break">
 </div>
-<div class="section" title="12.2.7. The Condor Profile Namespace">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
 <a name="condor_profiles"></a>12.2.7. The Condor Profile Namespace</h3></div></div></div>
 <p>The Condor submit file controls every detail how and where a job
@@ -544,7 +544,7 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
       a lot of condor commands in the submit files depending upon the job, and
       where it is being run.</p>
 <div class="table">
-<a name="idp31951888"></a><p class="title"><b>Table 12.4. Useful Condor Commands</b></p>
+<a name="idp54891728"></a><p class="title"><b>Table 12.4. Useful Condor Commands</b></p>
 <div class="table-contents"><table summary="Useful Condor Commands" border="1">
 <colgroup>
 <col>
@@ -669,7 +669,7 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
       overridden through some different means. Table 5 shows prohibited Condor
       commands.</p>
 <div class="table">
-<a name="idp47119392"></a><p class="title"><b>Table 12.5. Table 5: Condor commands prohibited in condor profiles</b></p>
+<a name="idp53479952"></a><p class="title"><b>Table 12.5. Table 5: Condor commands prohibited in condor profiles</b></p>
 <div class="table-contents"><table summary="Table 5: Condor commands prohibited in condor profiles" border="1">
 <colgroup>
 <col>
@@ -704,7 +704,7 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
 </div>
 <br class="table-break">
 </div>
-<div class="section" title="12.2.8. The Dagman Profile Namespace">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
 <a name="dagman_profiles"></a>12.2.8. The Dagman Profile Namespace</h3></div></div></div>
 <p>DAGMan is Condor's workflow manager. While planners generate most
@@ -726,7 +726,7 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
 <p>Table 6 shows the keys in the dagman profile domain that are
       understood by Pegasus and can be associated at a per job basis.</p>
 <div class="table">
-<a name="idp38277744"></a><p class="title"><b>Table 12.6. Useful dagman Commands that can be associated at a per job
+<a name="idp60427872"></a><p class="title"><b>Table 12.6. Useful dagman Commands that can be associated at a per job
           basis</b></p>
 <div class="table-contents"><table summary="Useful dagman Commands that can be associated at a per job
           basis" border="1">
@@ -962,7 +962,7 @@ Scope       :</strong></span> Properties<br>
 </div>
 <br class="table-break">
 </div>
-<div class="section" title="12.2.9. The Pegasus Profile Namespace">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
 <a name="pegasus_profiles"></a>12.2.9. The Pegasus Profile Namespace</h3></div></div></div>
 <p>The <span class="emphasis"><em>pegasus</em></span> profiles allow users to configure
@@ -973,7 +973,7 @@ Scope       :</strong></span> Properties<br>
 <p>Table 8 shows some of the useful configuration option Pegasus
       understands.</p>
 <div class="table">
-<a name="idp40964208"></a><p class="title"><b>Table 12.8. Useful pegasus Profiles.</b></p>
+<a name="idp60462256"></a><p class="title"><b>Table 12.8. Useful pegasus Profiles.</b></p>
 <div class="table-contents"><table summary="Useful pegasus Profiles." border="1">
 <colgroup>
 <col>
@@ -1057,13 +1057,13 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
               additional jobs added by Pegasus during the planning opertation.
               Possible values are <span class="bold"><strong><span class="emphasis"><em>Kickstart |
               NoGridStart</em></span></strong></span> | PegasusLite | Distribute at
-              the moment. <div class="note" title="Note" style="margin-left: 0.5in; margin-right: 0.5in;">
+              the moment. <div class="note" style="margin-left: 0.5in; margin-right: 0.5in;">
 <h3 class="title">Note</h3>
 <p>This profile should only be set by users if you know
                   what you are doing. Otherwise, let Pegasus do the right
                   thing based on your configuration.</p>
 </div>
-<div class="variablelist"><dl>
+<div class="variablelist"><dl class="variablelist">
 <dt><span class="term">Kickstart</span></dt>
 <dd>
                        By default, all jobs executed are launched using a lightweight C executable called pegasus-kickstart. This generates valuable runtime provenance information for the job as it is executed on a remote node. This information serves as the basis for the monitoring and debugging capabilities provided by Pegasus. 
@@ -1340,7 +1340,7 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
 </div>
 <br class="table-break">
 </div>
-<div class="section" title="12.2.10. The Hints Profile Namespace">
+<div class="section">
 <div class="titlepage"><div><div><h3 class="title">
 <a name="hints_profiles"></a>12.2.10. The Hints Profile Namespace</h3></div></div></div>
 <p>The <span class="emphasis"><em>hints</em></span> namespace allows users to override
@@ -1352,7 +1352,7 @@ Scope       :</strong></span> TC, SC, DAX, Properties<br>
       other profiles.</p>
 <p></p>
 <div class="table">
-<a name="idp39624448"></a><p class="title"><b>Table 12.9. Useful Hints Profile Keys</b></p>
+<a name="idp50312608"></a><p class="title"><b>Table 12.9. Useful Hints Profile Keys</b></p>
 <div class="table-contents"><table summary="Useful Hints Profile Keys" border="1">
 <colgroup>
 <col>
