@@ -12,15 +12,15 @@
 </tr></table>
 <hr>
 </div>
-<div class="section">
+<div class="section" title="4.4. Executable Discovery (Transformation Catalog)">
 <div class="titlepage"><div><div><h2 class="title" style="clear: both">
 <a name="transformation"></a>4.4. Executable Discovery (Transformation Catalog)</h2></div></div></div>
-<div class="toc"><dl class="toc">
+<div class="toc"><dl>
 <dt><span class="section"><a href="transformation.php#tc-Text">4.4.1. MultiLine Text based TC (Text)</a></span></dt>
 <dt><span class="section"><a href="transformation.php#tc-File">4.4.2. Singleline Text based TC (File)</a></span></dt>
 <dt><span class="section"><a href="transformation.php#tc-Database">4.4.3. Database TC (Database)</a></span></dt>
 <dt><span class="section"><a href="transformation.php#pegasus-tc-client">4.4.4. TC Client pegasus-tc-client</a></span></dt>
-<dt><span class="section"><a href="transformation.php#idp51816304">4.4.5. TC Converter Client pegasus-tc-converter</a></span></dt>
+<dt><span class="section"><a href="transformation.php#idp37650928">4.4.5. TC Converter Client pegasus-tc-converter</a></span></dt>
 </dl></div>
 <p>The Transformation Catalog maps logical transformations to physical
     executables on the system. It also provides additional information about
@@ -39,7 +39,7 @@
 </ol></div>
 <p>In this guide we will look at the format of the Multiline Text based
     TC.</p>
-<div class="section">
+<div class="section" title="4.4.1. MultiLine Text based TC (Text)">
 <div class="titlepage"><div><div><h3 class="title">
 <a name="tc-Text"></a>4.4.1. MultiLine Text based TC (Text)</h3></div></div></div>
 <p>The multile line text based TC is the new default TC in Pegasus.
@@ -116,10 +116,10 @@
             file&gt;</code></em></strong></span></p></li>
 </ol></div>
 </div>
-<div class="section">
+<div class="section" title="4.4.2. Singleline Text based TC (File)">
 <div class="titlepage"><div><div><h3 class="title">
 <a name="tc-File"></a>4.4.2. Singleline Text based TC (File)</h3></div></div></div>
-<div class="warning" style="margin-left: 0.5in; margin-right: 0.5in;">
+<div class="warning" title="Warning" style="margin-left: 0.5in; margin-right: 0.5in;">
 <h3 class="title">Warning</h3>
 <p>This format is now deprecated in favor of the multiline TC. If
         you are still using the single line TC you should convert it to
@@ -148,7 +148,7 @@ site1 sys::date:1.0 /usr/bin/date  INSTALLED INTEL32::LINUX:FC4.2:3.6 ENV::PATH=
 <li class="listitem">
 <p><span class="bold"><strong>type</strong></span> - The type of
           transformation. Can have on of two values</p>
-<div class="itemizedlist"><ul class="itemizedlist" style="list-style-type: disc; ">
+<div class="itemizedlist"><ul class="itemizedlist" type="disc">
 <li class="listitem"><p><span class="bold"><strong>INSTALLED</strong></span>: This means
               that the transformation is installed on the remote site</p></li>
 <li class="listitem"><p><span class="bold"><strong>STAGEABLE</strong></span>: This means
@@ -174,7 +174,7 @@ site1 sys::date:1.0 /usr/bin/date  INSTALLED INTEL32::LINUX:FC4.2:3.6 ENV::PATH=
           key and value can be any strings. Remember to quote the value with
           double quotes. If you need to specify several profiles you can do it
           in several ways</p>
-<div class="itemizedlist"><ul class="itemizedlist" style="list-style-type: disc; ">
+<div class="itemizedlist"><ul class="itemizedlist" type="disc">
 <li class="listitem">
 <p>NS1::KEY1="VALUE1",KEY2="VALUE2";NS2::KEY3="VALUE3",KEY4="VALUE4"</p>
 <p>This is the most optimized form. Multiple key values for
@@ -198,7 +198,7 @@ site1 sys::date:1.0 /usr/bin/date  INSTALLED INTEL32::LINUX:FC4.2:3.6 ENV::PATH=
             file&gt;</code></em></strong></span></p></li>
 </ol></div>
 </div>
-<div class="section">
+<div class="section" title="4.4.3. Database TC (Database)">
 <div class="titlepage"><div><div><h3 class="title">
 <a name="tc-Database"></a>4.4.3. Database TC (Database)</h3></div></div></div>
 <p>The database TC alows you to use a relational database. To use the
@@ -219,7 +219,7 @@ site1 sys::date:1.0 /usr/bin/date  INSTALLED INTEL32::LINUX:FC4.2:3.6 ENV::PATH=
             password&gt;</code></em></strong></span></p></li>
 </ol></div>
 </div>
-<div class="section">
+<div class="section" title="4.4.4. TC Client pegasus-tc-client">
 <div class="titlepage"><div><div><h3 class="title">
 <a name="pegasus-tc-client"></a>4.4.4. TC Client pegasus-tc-client</h3></div></div></div>
 <p>We need to map our declared transformations (preprocess,
@@ -240,7 +240,7 @@ Output Filename: /dev/fd/1</code></pre>
 <p>Now we need to map all 3 transformations onto the "keg"
       executable. We place these mappings in our File transformation catalog
       for site clus1.</p>
-<div class="note" style="margin-left: 0.5in; margin-right: 0.5in;">
+<div class="note" title="Note" style="margin-left: 0.5in; margin-right: 0.5in;">
 <h3 class="title">Note</h3>
 <p>In earlier version of Pegasus users had to define entries for
         Pegasus executables such as transfer, replica client, dirmanager, etc
@@ -272,9 +272,9 @@ clus1    black::analyze:1.0    gsiftp://clus1.com/opt/nfs/vdt/pegasus/bin/keg
                 STAGEABLE    INTEL32::LINUX</code></pre>
 <p></p>
 </div>
-<div class="section">
+<div class="section" title="4.4.5. TC Converter Client pegasus-tc-converter">
 <div class="titlepage"><div><div><h3 class="title">
-<a name="idp51816304"></a>4.4.5. TC Converter Client pegasus-tc-converter</h3></div></div></div>
+<a name="idp37650928"></a>4.4.5. TC Converter Client pegasus-tc-converter</h3></div></div></div>
 <p>Pegasus 3.0 by default now parses a file based multiline textual
       format of a Transformation Catalog. The new Text format is explained in
       detail in the chapter on Catalogs.</p>
